import {select, csv, scaleLinear, max, scalePoint, 
        axisLeft, axisBottom, format} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = dd => {
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top:50, right:50, bottom:80, left: 150};
  const innerwidth = width-margin.right-margin.left;
  const innerheight = height-margin.top-margin.bottom
  
  const xScale = scaleLinear()
  	.domain([0, max(dd, xValue)])
  	.range([0, innerwidth])
  	.nice();
  
  const yScale = scalePoint()
  	.domain(dd.map(yValue))
  	.range([0, innerheight])
  	.padding(.7)
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  const xTickFormat = number => 
  	format('.3s')(number)
  	.replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xTickFormat)
  	.tickSize(-innerheight);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerwidth);
  
  g.append('g').call(yAxis)
    .selectAll('.domain')
  		.remove()
  	
  const xAxisG = g.append('g').call(xAxis)
 		.attr('transform', `translate(0, ${innerheight})`);
  
  
 xAxisG.selectAll('.domain').remove();
  
  
  
  
	g.selectAll('circle').data(dd)
  	.enter().append('circle')
  		.attr('cx', pick => xScale(xValue(pick)))
  		.attr('cy', pick => yScale(yValue(pick)))
  		.attr('r', 10)
  
  g.append('text')
  	.attr('y', -10)
		.text('Top 10 Population Country');
  
};

	

csv('data.csv').then(data => {
  data.forEach(d => {
  d.population = +d.population *1000
  })
	render(data)
});



